package rest;

import java.io.File;
import java.math.BigDecimal;
import java.util.List;

import javax.ws.rs.Consumes;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;

import sklep.db.DBConnection;
import sklep.db.DBException;
import sklep.db.ProductDAO;
import sklep.db.RecordNotFound;
import sklep.model.Product;
import sklep.photo.PhotoUtil;

// W tej klasie używany jest format JSON (tylko nie dla zdjęć)
@Path("/products.json")
@Produces("application/json")
@Consumes("application/json")
public class RProductsJson {

    @GET
    public List<Product> readAll() throws DBException {
        try(DBConnection db = DBConnection.open()) {
            ProductDAO productDAO = db.productDAO();
            return productDAO.readAll();
        }
    }
    
    @GET
    @Path("/{id}")
    public Product readOne(@PathParam("id") int productId) throws DBException, RecordNotFound {
        try(DBConnection db = DBConnection.open()) {
            ProductDAO productDAO = db.productDAO();
            return productDAO.findById(productId);
        }
    }
    
    @GET
    @Path("/{id}/price")
    public BigDecimal getPrice(@PathParam("id") int productId) throws DBException, RecordNotFound {
        try(DBConnection db = DBConnection.open()) {
            ProductDAO productDAO = db.productDAO();
            return productDAO.findById(productId).getPrice();
        }
    }
    
    // W metodach obsługujących PUT i POST powinien występować jeden paramrtr bez żadnej adnotacji.
    // To właśnie w tym parametrze zostanie przekazana treść przysłana w zapytaniu ("body" / "content" / "entity")
    @PUT
    @Path("/{id}/price")
    public void setPrice(
                @PathParam("id") int productId,
                BigDecimal newPrice
            ) throws DBException, RecordNotFound {
        try(DBConnection db = DBConnection.open()) {
            ProductDAO productDAO = db.productDAO();
            Product product = productDAO.findById(productId);
            product.setPrice(newPrice);
            productDAO.update(product);
            db.commit();
        }
    }
    
    // W tej wersji w wyniku zwracamy uzupełniony obiekt - będzie widać jakie ma ID.
    // Tutaj mamy jedną ogólnę metodę do zapisywnaia rekordów Product - nie ważne czy INSERT, czy UPDATE.
    // Jest to bardziej rozbudowane i opisane w wersji Spring → zobacz tam, aby przeczytac "teorię" PUT/POST.
    @POST
    public Product add(Product product) throws DBException {
        try(DBConnection db = DBConnection.open()) {
            ProductDAO productDAO = db.productDAO();
            productDAO.save(product);
            db.commit();
            return product;
        }
    }
    
    // W JAX-RS dane "z pliku" można zwracać na kilka sposobów.
    // Oprócz byte[] można też bezpośrednio zwrócić obiekt File.
    @GET
    @Path("/{id}/photo")
    @Produces("image/jpeg")
    public File photo(@PathParam("id") int productId) throws DBException, RecordNotFound {
        return PhotoUtil.getFile(productId);
    }
}
