package ogloszenia.rest5;

import java.math.BigDecimal;
import java.util.List;

import javax.ws.rs.Consumes;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.QueryParam;
import javax.ws.rs.WebApplicationException;

import ogloszenia.baza.DostepDoBazy;
import ogloszenia.baza.OgloszeniaDAO;
import ogloszenia.exn.BladBazyDanych;
import ogloszenia.model.Samochodowe;

@Path("/ogloszenia")
public class ROgloszenia {

	@Produces({"application/xml", "application/json", "text/plain"})
	@GET
	public List<Samochodowe> odczytajWszystkie(
			@QueryParam("min") BigDecimal min,
			@QueryParam("max") BigDecimal max) {
		try(DostepDoBazy db = new DostepDoBazy()) {
			OgloszeniaDAO dao = db.ogloszeniaDAO();
			return dao.odczytajWedlugCeny(min, max);
		} catch (BladBazyDanych e) {
			throw new WebApplicationException("Błąd bazy danych: " + e.getMessage(), 500);
		}
	}
	
	@GET
	@Produces("text/html")
	public String odczytajWszystkieHtml(
			@QueryParam("min") BigDecimal min,
			@QueryParam("max") BigDecimal max) {

		try (DostepDoBazy db = new DostepDoBazy()) {
			OgloszeniaDAO dao = db.ogloszeniaDAO();
			List<Samochodowe> ogloszenia = dao.odczytajWedlugCeny(min, max);

			StringBuilder wynik = new StringBuilder();
			wynik.append("<html><body>");
			for (Samochodowe ogl : ogloszenia) {
				wynik.append(ogl.dajHtml());
			}
			wynik.append("</body></html>");
			return wynik.toString();
		} catch (BladBazyDanych e) {
			throw new WebApplicationException("Błąd bazy danych: " + e.getMessage(), 500);
		}
	}

	@POST
	@Consumes({"application/xml", "application/json"})
	@Produces({"application/xml", "application/json"})
	public Samochodowe zapiszOgloszenie(Samochodowe ogloszenie) {
		try(DostepDoBazy db = new DostepDoBazy()) {
			OgloszeniaDAO dao = db.ogloszeniaDAO();
			dao.zapisz(ogloszenie);
			// zwracam uzupełniony obiekt - dzięki temu klient dowie się jakie jest jego id
			return ogloszenie;
		} catch (BladBazyDanych e) {
			throw new WebApplicationException("Błąd bazy danych: " + e.getMessage(), 500);
		}
	}
	
	@Path("/{id}")
	public ROgloszenie obslugaJednegoOgloszenia(@PathParam("id") int idOgloszenia) {
		// To oznacza, że obsługą zapytań kierowanych pod adresy /ogloszenia/????
		// niezależnie od tego, czy zapytanie jest typu GET, POST, itd...
		// zajmie się obiekt innej klasy:
		return new ROgloszenie(idOgloszenia);
	}
	
}
